#### R codes for Hisano et al. 2024 ####

rm(list=ls())

library(rlang);library(vctrs)
library(lme4);library(lmerTest)
library(nlme);library(piecewiseSEM);
library(parameters);library(sjstats);library(pwr)
library(lavaan); library(lavaan.survey);library(survey)
library(boot);library(Rfit);library(relaimpo)
library(ggplot2);library(ggfortify);library(adespatial)
library(grid);library(gridExtra);library(ggsci)
library(ggpubr);library(maps);library(Hmisc)
library(gtable);library(plyr);library(ggbreak)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils);library(multcomp)
library(SoDA);library(spdep);library(spaMM)
library(sjPlot);library(sjmisc);library(car)
library(tidyverse);library(gapminder);library(scales)
library(ggiraph);library(ggiraphExtra);library(effects)
library(AICcmodavg);library(jtools);library(interactions)
library(ggeffects);library(randomForest);library(stringr)

setwd("~/To Figshare")
arid<-fread("Hisano_et_al_2024.csv")

#Scaling all the explanatory variables
arid[,":="(Year=(IniY+FinY)/2,
           SA1=(IniSA+FinSA)/2,
           SI=scale(SI1),
           DrainNum=scale(DrainNum1),
           AIave=scale(AIave1),
           MATave=scale(MATave1))] %>% 
  .[,":="(Y=scale(Year),
          SA=scale(SA1),
          logSA1=log(SA1),
          logSI=scale(log(SI1)),
          lognbsp1=log(Spnbsp1))] %>% 
  .[,":="(ATA=scale(ATA1),
          DI=scale(DI1),
          DIg=scale(DIg1),
          DIs=scale(DIs1),
          logSA=scale(logSA1),
          logDrainNum1=log(DrainNum1))] %>% 
  .[,":="(logFD1=log(SpFD1+1))] %>% 
  .[,":="(SpFD=scale(SpFD1),
          logFD=scale(logFD1),
          SpCWM.PC1=scale(SpCWM.PC11),
          SpCWM.PC2=scale(SpCWM.PC21),
          Spnbsp=scale(Spnbsp1),
          lognbsp=scale(lognbsp1),
          logDrainNum=scale(logDrainNum1),
          logAGBGI=log(AGBGI+1),
          logIniBio=scale(log(IniBio)))]

# Figs. 3 and S1 ---------------------------------------
mb<-lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
           Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
           MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           (1|PLOT_ID),
         control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
         arid)
AIC(mb)

summary(mb)$co
anova(mb)
max(vif(mb))
r.squaredGLMM(mb)

coefmean.mb<-summary(mb)$co[,1]

#Calculate how much % Year decreases growth
high=max(arid$Y)
low=min(arid$Y)
int=summary(mb)$co["(Intercept)",1]
b=summary(mb)$co["Y",1]
decline=((exp(int+b*high)-1)-(exp(int+b*low)-1))/(exp(int+b*low)-1)*100
decline/(max(arid$Year)-min(arid$Year))*10

#Calculate how much % FD increases growth
high=max(arid$logFD)
low=min(arid$logFD)
int=summary(mb)$co["(Intercept)",1]
b=summary(mb)$co["logFD",1]
((exp(int+b*high)-1)-(exp(int+b*low)-1))/(exp(int+b*low)-1)*100

#### MATave ####
arid[,":="(AGBGI_MATave_mean=coefmean.mb["(Intercept)"]+coefmean.mb["MATave"]*MATave,
           AGBGI_MATave=coefmean.mb["(Intercept)"]+coefmean.mb["MATave"]*MATave+resid(mb))]

df.mb_MATave<-ggpredict(mb, terms = c("MATave[all]"), back.transform = TRUE)
df.mb_MATave %>% as_tibble()

G3MATave<-ggplot()+
  geom_point(data=arid,aes(x=MATave1,y=exp(AGBGI_MATave)-1),col="thistle1",size=2)+
  geom_ribbon(data=df.mb_MATave,aes(x=(x*sd(arid$MATave1)+mean(arid$MATave1)),#needed add abs(min) to transform to sqrt
                                    ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_MATave,aes(x=(x*sd(arid$MATave1)+mean(arid$MATave1)),
                                  y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "black"))+
  coord_cartesian(ylim=c(0,6))+
  scale_y_continuous(breaks = c(0,2,4,6))+
  scale_x_continuous(breaks = c(-4,0,4,8))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Long-term average of MAT"," (",~degree*C,")")))

#### AIave ####
arid[,":="(AGBGI_AIave_mean=coefmean.mb["(Intercept)"]+coefmean.mb["AIave"]*AIave,
           AGBGI_AIave=coefmean.mb["(Intercept)"]+coefmean.mb["AIave"]*AIave+resid(mb))]

df.mb_AIave<-ggpredict(mb, terms = c("AIave[all]"), back.transform = TRUE)
df.mb_AIave %>% as_tibble()

G3AIave<-ggplot()+
  geom_point(data=arid,aes(x=AIave1,y=exp(AGBGI_AIave)-1),col="thistle1",size=2)+
  geom_ribbon(data=df.mb_AIave,aes(x=(x*sd(arid$AIave1)+mean(arid$AIave1)),#needed add abs(min) to transform to sqrt
                                   ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_AIave,aes(x=(x*sd(arid$AIave1)+mean(arid$AIave1)),
                                 y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "white"))+
  coord_cartesian(ylim=c(0,6))+
  scale_y_continuous(breaks = c(0,2,4,6))+
  #scale_x_continuous(breaks = c(-4,0,4,8))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Long-term average of AI"," (unitless)")))

#### SI ####
arid[,":="(AGBGI_SI_mean=coefmean.mb["(Intercept)"]+coefmean.mb["SI"]*SI,
           AGBGI_SI=coefmean.mb["(Intercept)"]+coefmean.mb["SI"]*SI+resid(mb))]

df.mb_SI<-ggpredict(mb, terms = c("SI[all]"), back.transform = TRUE)
df.mb_SI %>% as_tibble()

G3SI<-ggplot()+
  geom_point(data=arid,aes(x=SI1,y=exp(AGBGI_SI)-1),col="thistle1",size=2)+
  geom_ribbon(data=df.mb_SI,aes(x=(x*sd(arid$SI1)+mean(arid$SI1)),#needed add abs(min) to transform to sqrt
                                ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_SI,aes(x=(x*sd(arid$SI1)+mean(arid$SI1)),
                              y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "black"))+
  coord_cartesian(ylim=c(0,6))+
  scale_y_continuous(breaks = c(0,2,4,6))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Site index"," (m)")))

#### logSA ####
arid[,":="(AGBGI_logSA_mean=coefmean.mb["(Intercept)"]+coefmean.mb["logSA"]*logSA,
           AGBGI_logSA=coefmean.mb["(Intercept)"]+coefmean.mb["logSA"]*logSA+resid(mb))]

df.mb_logSA<-ggpredict(mb, terms = c("logSA[all]"), back.transform = TRUE)
df.mb_logSA %>% as_tibble()
summary(df.mb_logSA %>% as_tibble())

G3logSA<-ggplot()+
  geom_point(data=arid,aes(x=SA1,y=exp(AGBGI_logSA)-1),col="thistle1",size=2)+
  geom_ribbon(data=df.mb_logSA,aes(x=exp(x*sd(arid$logSA1)+mean(arid$logSA1)),
                                   ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_logSA,aes(x=exp(x*sd(arid$logSA1)+mean(arid$logSA1)),y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "white"))+
  coord_cartesian(ylim=c(0,6))+
  scale_y_continuous(breaks = c(0,2,4,6))+
  scale_x_continuous(breaks = c(60,120,180,240))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Stand age (yrs)")))

#### Y ####
arid[,":="(AGBGI_Y_mean=coefmean.mb["(Intercept)"]+coefmean.mb["Y"]*Y,
           AGBGI_Y=coefmean.mb["(Intercept)"]+coefmean.mb["Y"]*Y+resid(mb))]

df.mb_Y<-ggpredict(mb, terms = c("Y[all]"))
df.mb_Y %>% as_tibble()

G3Y<-ggplot()+
  geom_point(data=arid,aes(x=Year,y=exp(AGBGI_Y)-1),col="thistle1",size=2)+
  geom_ribbon(data=df.mb_Y,aes(x=x*sd(arid$Year)+mean(arid$Year),
                               ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_Y,aes(x=x*sd(arid$Year)+mean(arid$Year),y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "black"))+
  coord_cartesian(ylim=c(1,6))+
  scale_y_continuous(breaks = c(1,2,3,4,5,6))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Calendar year")))

#### SpCWM.PC1 ####
arid[,":="(AGBGI_SpCWM.PC1_mean=coefmean.mb["(Intercept)"]+coefmean.mb["SpCWM.PC1"]*SpCWM.PC1,
           AGBGI_SpCWM.PC1=coefmean.mb["(Intercept)"]+coefmean.mb["SpCWM.PC1"]*SpCWM.PC1+resid(mb))]

df.mb_SpCWM.PC1<-ggpredict(mb, terms = c("SpCWM.PC1[all]"), back.transform = TRUE)
df.mb_SpCWM.PC1 %>% as_tibble()

G3SpCWM.PC1<-ggplot()+
  geom_point(data=arid,aes(x=SpCWM.PC11,y=exp(AGBGI_SpCWM.PC1)-1),
             col="thistle1",size=2)+
  geom_ribbon(data=df.mb_SpCWM.PC1,aes(x=(x*sd(arid$SpCWM.PC11)+mean(arid$SpCWM.PC11)),#needed add abs(min) to transform to sqrt
                                       ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_SpCWM.PC1,aes(x=(x*sd(arid$SpCWM.PC11)+mean(arid$SpCWM.PC11)),
                                     y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "black"))+
  coord_cartesian(ylim=c(1,6))+
  scale_y_continuous(breaks = c(1,2,3,4,5,6))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Functional identity"," (CW",M[PC1],")")))

#### SpCWM.PC2 ####
arid[,":="(AGBGI_SpCWM.PC2_mean=coefmean.mb["(Intercept)"]+coefmean.mb["SpCWM.PC2"]*SpCWM.PC2,
           AGBGI_SpCWM.PC2=coefmean.mb["(Intercept)"]+coefmean.mb["SpCWM.PC2"]*SpCWM.PC2+resid(mb))]

df.mb_SpCWM.PC2<-ggpredict(mb, terms = c("SpCWM.PC2[all]"), back.transform = TRUE)
df.mb_SpCWM.PC2 %>% as_tibble()

G3SpCWM.PC2<-ggplot()+
  geom_point(data=arid,aes(x=SpCWM.PC21,y=exp(AGBGI_SpCWM.PC2)-1),
             col="thistle1",size=2)+
  geom_ribbon(data=df.mb_SpCWM.PC2,aes(x=(x*sd(arid$SpCWM.PC21)+mean(arid$SpCWM.PC21)),#needed add abs(min) to transform to sqrt
                                       ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_SpCWM.PC2,aes(x=(x*sd(arid$SpCWM.PC21)+mean(arid$SpCWM.PC21)),
                                     y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "white"))+
  coord_cartesian(ylim=c(1,6))+
  scale_y_continuous(breaks = c(1,2,3,4,5,6))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Functional identity"," (CW",M[PC2],")")))

#### logFD ####
arid[,":="(AGBGI_logFD_mean=coefmean.mb["(Intercept)"]+coefmean.mb["logFD"]*logFD,
           AGBGI_logFD=coefmean.mb["(Intercept)"]+coefmean.mb["logFD"]*logFD+resid(mb))]

df.mb_logFD<-ggpredict(mb, terms = c("logFD[all]"), back.transform = TRUE)
df.mb_logFD %>% as_tibble()

G3logFD<-ggplot()+
  geom_point(data=arid,aes(x=SpFD1,y=exp(AGBGI_logFD)-1),
             col="thistle1",size=2)+
  geom_ribbon(data=df.mb_logFD,
              aes(x=exp(x*sd(arid$logFD1)+mean(arid$logFD1))-1,#log-transform is complected to add abs(min) and 1
                  ymin=exp(conf.low)-1,ymax=exp(conf.high)-1),
              fill="lightsalmon",alpha=0.4)+
  geom_line(data=df.mb_logFD,
            aes(x=exp(x*sd(arid$logFD1)+mean(arid$logFD1))-1,
                y=exp(predicted)-1),
            colour="tomato3",size=0.8,linetype="solid")+
  theme(axis.line.x = element_line(),
        axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank(),
        axis.title.y = element_text(colour = "white"))+
  coord_cartesian(ylim=c(1,6))+
  scale_y_continuous(breaks = c(1,2,3,4,5,6))+
  scale_x_continuous(breaks = c(0.0,0.1,0.2))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Functional diversity (FD)")))

#### Bind figures ####
Temporal<-ggarrange(G3Y,G3logFD,
                    G3SpCWM.PC1,G3SpCWM.PC2,
                    labels = c("A","B",
                               "C","D"),
                    ncol = 2, nrow = 2,
                    font.label = list(size = 13))

setwd("~/To Figshare")
ggsave(file="Fig.2_Effect_Size.tiff",
       plot=Temporal,dpi=300,width=7.5,height=7,compression="lzw")

#### Bind SI figures ####
Suppl<-ggarrange(G3SI,G3logSA,
                 G3MATave,G3AIave,
                 labels = c("A","B",
                            "C","D"),
                 ncol = 2, nrow = 2,
                 font.label = list(size = 12))

setwd("~/To Figshare")
ggsave(file="Fig.S_Covariates_Effect_Size.tiff",
       plot=Suppl,dpi=300,width=7,height=6,compression="lzw")

# Fig. 5 ------------------------------------------------------------------
mb<-lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
           Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
           MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           (1|PLOT_ID),
         control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
         arid)

## Unscaled model for graphical purpose with interact_plot
mb1<-lmer(logAGBGI~Year+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21+MATave1+AIave1+SI1+logSA1+
            Year:(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
            MATave1:(Year+(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21))+
            AIave1:(Year+(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21))+
            SI1:(Year+(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21))+
            logSA1:(Year+(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21))+
            (1|PLOT_ID),
          control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
          arid)

#### SpCWM.PC1 ####
mb1_SpCWM.PC11_data<-interact_plot(mb1,pred = Year,modx = SpCWM.PC11,data = arid,
                                   modx.values=round(c(min(arid$SpCWM.PC11),mean(arid$SpCWM.PC11),max(arid$SpCWM.PC11)),1),
                                   interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC11),1),round(mean(arid$SpCWM.PC11),1),round(max(arid$SpCWM.PC11),1))
mb1_SpCWM.PC11_data[modx_group=="-3.6",":="(modx_group="-3.6 (Min)")] %>% 
  .[modx_group=="-0.4",":="(modx_group="-0.4 (Mean)")] %>% 
  .[modx_group=="4.6",":="(modx_group="4.6 (Max)")]
table(mb1_SpCWM.PC11_data$modx_group)

mb1_SpCWM.PC11_data$modx_group<-factor(mb1_SpCWM.PC11_data$modx_group,
                                       levels<-c("4.6 (Max)","-0.4 (Mean)","-3.6 (Min)"))#Change order

Grow_SpCWM.PC1<-ggplot(mb1_SpCWM.PC11_data,aes(x=Year,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=Year,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=2.0)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC1])))+
  xlab(expression(paste("Calendar year")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),
        axis.title.y = element_text(colour = "white"),axis.title.x = element_text(colour = "black"),
        legend.position=c(0.8,0.85),legend.background = element_blank())+
  scale_x_continuous(breaks =c(1960, 1970, 1980, 1990, 2000, 2010))+
  scale_y_continuous(limits=c(NA,3.4),breaks = c(2.0,2.4,2.8,3.2))+
  ggtitle(expression(paste(CWM[PC1],": ",italic(P)," = 0.684,  ",
                           Year %*% CWM[PC1],": ",italic(P)," <0.001")))
Grow_SpCWM.PC1
round(summary(mb)$co["SpCWM.PC1",],3)
round(summary(mb)$co["Y:SpCWM.PC1",],3)

#### SpCWM.PC2 ####
mb1_SpCWM.PC21_data<-interact_plot(mb1,pred = Year,modx = SpCWM.PC21,data = arid,
                                   modx.values=round(c(min(arid$SpCWM.PC21),mean(arid$SpCWM.PC21),max(arid$SpCWM.PC21)),1),
                                   interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC21),1),round(mean(arid$SpCWM.PC21),1),round(max(arid$SpCWM.PC21),1))
mb1_SpCWM.PC21_data[modx_group=="-2.7",":="(modx_group="-2.7 (Min)")] %>% 
  .[modx_group=="0.5",":="(modx_group="0.5 (Mean)")] %>% 
  .[modx_group=="4",":="(modx_group="4.0 (Max)")]
table(mb1_SpCWM.PC21_data$modx_group)

mb1_SpCWM.PC21_data$modx_group<-factor(mb1_SpCWM.PC21_data$modx_group,
                                       levels<-c("4.0 (Max)","0.5 (Mean)","-2.7 (Min)"))#Change order

Grow_SpCWM.PC2<-ggplot(mb1_SpCWM.PC21_data,aes(x=Year,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=Year,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC2])))+
  xlab(expression(paste("")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),axis.title.y = element_text(colour = "white"),
        legend.position=c(0.8,0.85),legend.background = element_blank())+
  scale_x_continuous(breaks =c(1960, 1970, 1980, 1990, 2000, 2010))+
  scale_y_continuous(limits=c(NA,4.3),breaks = c(1.6,2.4,3.2,4.0))+
  ggtitle(expression(paste(CWM[PC2],": ",italic(P)," <0.001,  ",
                           Year %*% CWM[PC2],": ",italic(P)," = 0.162")))
Grow_SpCWM.PC2
round(summary(mb)$co["SpCWM.PC2",],3)
round(summary(mb)$co["Y:SpCWM.PC2",],3)

#### logFD ####
mb1_SpFD1_data<-interact_plot(mb1,pred = Year,modx = SpFD1,data = arid,
                              modx.values=round(c(min(arid$SpFD1),mean(arid$SpFD1),max(arid$SpFD1)),1),
                              interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpFD1),1),round(mean(arid$SpFD1),1),round(max(arid$SpFD1),1))
mb1_SpFD1_data[modx_group=="0",":="(modx_group="0.0 (Min)")] %>% 
  .[modx_group=="0.1",":="(modx_group="0.1 (Mean)")] %>% 
  .[modx_group=="0.3",":="(modx_group="0.3 (Max)")]
table(mb1_SpFD1_data$modx_group)

mb1_SpFD1_data$modx_group<-factor(mb1_SpFD1_data$modx_group,
                                  levels<-c("0.3 (Max)","0.1 (Mean)","0.0 (Min)"))#Change order

Grow_logFD<-ggplot(mb1_SpFD1_data,aes(x=Year,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=Year,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("FD")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("Calendar year")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),
        axis.title.y = element_text(colour = "black"),axis.title.x = element_text(colour = "white"),
        legend.position=c(0.8,0.85),legend.background = element_blank())+
  scale_x_continuous(breaks =c(1960, 1970, 1980, 1990, 2000, 2010))+
  scale_y_continuous(limits=c(NA,3.2),breaks = c(2.0,2.4,2.8,3.2))+
  ggtitle(expression(paste(FD,": ",italic(P)," <0.001,  ",
                           Year %*% FD,": ",italic(P)," = 0.702")))
Grow_logFD
round(summary(mb)$co["logFD",],3)
round(summary(mb)$co["Y:logFD",],3)

#### Bind figures ####
Temporal_Int<-ggarrange(Grow_logFD,Grow_SpCWM.PC1,Grow_SpCWM.PC2,
                        labels = c("A","B","C"),
                        ncol = 3, nrow = 1,
                        font.label = list(size = 12))

setwd("~/To Figshare")
ggsave(file="Fig.3_Year_Interaction.tiff",
       plot=Temporal_Int,dpi=300,width=12,height=4,compression="lzw")

# Fig. 6 ------------------------------------------------------------------
mbAD<-lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
             (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
             MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             (1|PLOT_ID),
           control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
           arid)
max(vif(mbAD))
summary(mbAD)$co
r.squaredGLMM(mbAD)

## Unscaled model for graphical purpose with interact_plot
mbAD1<-lmer(logAGBGI~(ATA1+DIg1)+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21+MATave1+AIave1+SI1+logSA1+
              (ATA1+DIg1):(log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
              MATave1:((ATA1+DIg1)+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
              AIave1:((ATA1+DIg1)+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
              SI1:((ATA1+DIg1)+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
              logSA1:((ATA1+DIg1)+log(SpFD1+1)+SpCWM.PC11+SpCWM.PC21)+
              (1|PLOT_ID),
            control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
            arid)

#Calculate how much % ATA increased over time
high=max(arid$Year)
low=min(arid$Year)
int=summary(lm(ATA1~Year,arid))$coef["(Intercept)",1]
b=summary(lm(ATA1~Year,arid))$coef["Year",1]
increase=((int+b*high)-(int+b*low))/abs(int+b*low)*100#an increase of 1.893 C over time; 200% increase
increase/(max(arid$Year)-min(arid$Year))#3.99% increase per year; or 40% increase per decade

#Calculate how much % DIg increased over time
high=max(arid$Year)
low=min(arid$Year)
int=summary(lm(DIg1~Year,arid))$coef["(Intercept)",1]
b=summary(lm(DIg1~Year,arid))$coef["Year",1]
increase=((int+b*high)-(int+b*low))/abs(int+b*low)*100#an increase of 0.266 DI over time; 101% increase
increase/(max(arid$Year)-min(arid$Year))#1.89% increase per year; or 19% increase per decade

#Calculate how much % AVPDg increased over time
high=max(arid$Year)
low=min(arid$Year)
int=summary(lm(AVPDg1~Year,arid))$coef["(Intercept)",1]
b=summary(lm(AVPDg1~Year,arid))$coef["Year",1]
increase=((int+b*high)-(int+b*low))/abs(int+b*low)*100#an increase of 0.02 AVPD over time; 378% increase
increase/(max(arid$Year)-min(arid$Year))#7.57% increase per year; or 76% increase per decade


#Calculate how much % high FD can maintain growth on average under climate change
high=max(arid$logFD)
low=min(arid$logFD)
int=summary(mbAD)$co["(Intercept)",1]
b=summary(mbAD)$co["logFD",1]
(exp(int+b*high)-1)/(exp(int+b*low)-1)*100

#Calculate how much % FD increases growth
high=max(arid$logFD)
low=min(arid$logFD)
int=summary(mbAD)$co["(Intercept)",1]
b=summary(mbAD)$co["logFD",1]
((exp(int+b*high)-1)-(exp(int+b*low)-1))/(exp(int+b*low)-1)*100#14% increase across the gradient of FD

#### ATA graphs ####
#### SpCWM.PC1 ####
mbAD1_SpCWM.PC11_data<-interact_plot(mbAD1,pred = ATA1,modx = SpCWM.PC11,data = arid,
                                     modx.values=round(c(min(arid$SpCWM.PC11),mean(arid$SpCWM.PC11),max(arid$SpCWM.PC11)),1),
                                     interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC11),1),round(mean(arid$SpCWM.PC11),1),round(max(arid$SpCWM.PC11),1))
mbAD1_SpCWM.PC11_data[modx_group=="-3.6",":="(modx_group="-3.6 (Min)")] %>% 
  .[modx_group=="-0.4",":="(modx_group="-0.4 (Mean)")] %>% 
  .[modx_group=="4.6",":="(modx_group="4.6 (Max)")]
table(mbAD1_SpCWM.PC11_data$modx_group)

mbAD1_SpCWM.PC11_data$modx_group<-factor(mbAD1_SpCWM.PC11_data$modx_group,
                                         levels<-c("4.6 (Max)","-0.4 (Mean)","-3.6 (Min)"))#Change order

Grow_ATA_SpCWM.PC1<-ggplot(mbAD1_SpCWM.PC11_data,aes(x=ATA1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=ATA1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=2)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC1])))+
  xlab(expression(paste("ATA (",~degree*C,")")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position=c(0.8,0.83),legend.background = element_blank(),
        axis.title.y = element_text(colour = "white"))+
  scale_y_continuous(limits=c(NA,3.6),breaks = c(2.2,2.8,3.4))+
  ggtitle(expression(atop(paste(CWM[PC1],": ",italic(P)," = 0.821,  "),
                          paste(ATA %*% CWM[PC1],": ",italic(P)," <0.001"))))
Grow_ATA_SpCWM.PC1
round(summary(mbAD)$co["SpCWM.PC1",],3)
round(summary(mbAD)$co["ATA:SpCWM.PC1",],3)

#### SpCWM.PC2 ####
mbAD1_SpCWM.PC21_data<-interact_plot(mbAD1,pred = ATA1,modx = SpCWM.PC21,data = arid,
                                     modx.values=round(c(min(arid$SpCWM.PC21),mean(arid$SpCWM.PC21),max(arid$SpCWM.PC21)),1),
                                     interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC21),1),round(mean(arid$SpCWM.PC21),1),round(max(arid$SpCWM.PC21),1))
mbAD1_SpCWM.PC21_data[modx_group=="-2.7",":="(modx_group="-2.7 (Min)")] %>% 
  .[modx_group=="0.5",":="(modx_group="0.5 (Mean)")] %>% 
  .[modx_group=="4",":="(modx_group="4.0 (Max)")]
table(mbAD1_SpCWM.PC21_data$modx_group)

mbAD1_SpCWM.PC21_data$modx_group<-factor(mbAD1_SpCWM.PC21_data$modx_group,
                                         levels<-c("4.0 (Max)","0.5 (Mean)","-2.7 (Min)"))#Change order

Grow_ATA_SpCWM.PC2<-ggplot(mbAD1_SpCWM.PC21_data,aes(x=ATA1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=ATA1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC2])))+
  xlab(expression(paste("ATA (",~degree*C,")")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position=c(0.8,0.83),
        legend.background = element_blank(),legend.title = element_text(size=10),axis.title.y = element_text(colour = "white"))+
  scale_y_continuous(limits=c(NA,4.6),breaks = c(2,3,4),labels = label_number(accuracy = 0.1))+
  ggtitle(expression(atop(paste(CWM[PC2],": ",italic(P)," <0.001,  "),
                          paste(ATA %*% CWM[PC2],": ",italic(P)," = 0.477"))))
Grow_ATA_SpCWM.PC2
round(summary(mbAD)$co["SpCWM.PC2",],3)
round(summary(mbAD)$co["ATA:SpCWM.PC2",],3)

#### logFD ####
mbAD1_SpFD1_data<-interact_plot(mbAD1,pred = ATA1,modx = SpFD1,data = arid,
                                modx.values=round(c(min(arid$SpFD1),mean(arid$SpFD1),max(arid$SpFD1)),1),
                                interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpFD1),1),round(mean(arid$SpFD1),1),round(max(arid$SpFD1),1))
mbAD1_SpFD1_data[modx_group=="0",":="(modx_group="0.0 (Min)")] %>% 
  .[modx_group=="0.1",":="(modx_group="0.1 (Mean)")] %>% 
  .[modx_group=="0.3",":="(modx_group="0.3 (Max)")]
table(mbAD1_SpFD1_data$modx_group)

mbAD1_SpFD1_data$modx_group<-factor(mbAD1_SpFD1_data$modx_group,
                                    levels<-c("0.3 (Max)","0.1 (Mean)","0.0 (Min)"))#Change order

Grow_ATA_logFD<-ggplot(mbAD1_SpFD1_data,aes(x=ATA1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=ATA1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("FD")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("ATA (",~degree*C,")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position=c(0.8,0.83),
        legend.background = element_blank(),legend.title = element_text(size=10))+
  scale_y_continuous(limits=c(NA,3.2),breaks = c(2.0,2.4,2.8,3.2))+
  ggtitle(expression(atop(paste(FD,": ",italic(P)," <0.001,  "),
                          paste(ATA %*% FD,": ",italic(P)," = 0.622"))))
Grow_ATA_logFD
round(summary(mbAD)$co["logFD",],3)
round(summary(mbAD)$co["ATA:logFD",],3)

#### DIg graphs ####
#### SpCWM.PC1 ####
mbAD1_SpCWM.PC11_data<-interact_plot(mbAD1,pred = DIg1,modx = SpCWM.PC11,data = arid,
                                     modx.values=round(c(min(arid$SpCWM.PC11),mean(arid$SpCWM.PC11),max(arid$SpCWM.PC11)),1),
                                     interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC11),1),round(mean(arid$SpCWM.PC11),1),round(max(arid$SpCWM.PC11),1))
mbAD1_SpCWM.PC11_data[modx_group=="-3.6",":="(modx_group="-3.6 (Min)")] %>% 
  .[modx_group=="-0.4",":="(modx_group="-0.4 (Mean)")] %>% 
  .[modx_group=="4.6",":="(modx_group="4.6 (Max)")]
table(mbAD1_SpCWM.PC11_data$modx_group)

mbAD1_SpCWM.PC11_data$modx_group<-factor(mbAD1_SpCWM.PC11_data$modx_group,
                                         levels<-c("4.6 (Max)","-0.4 (Mean)","-3.6 (Min)"))#Change order

Grow_DIg_SpCWM.PC1<-ggplot(mbAD1_SpCWM.PC11_data,aes(x=DIg1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=DIg1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC1])))+
  xlab(expression(paste("DI (unitless)")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position="none",
        axis.title.y = element_text(colour = "white"))+
  scale_y_continuous(limits=c(NA,3.2),breaks = c(2.0,2.4,2.8,3.2))+
  ggtitle(expression(atop(paste(CWM[PC1],": ",italic(P)," = 0.821,  "),
                          paste(DI %*% CWM[PC1],": ",italic(P)," = 0.620"))))
Grow_DIg_SpCWM.PC1
round(summary(mbAD)$co["SpCWM.PC1",],3)
round(summary(mbAD)$co["DIg:SpCWM.PC1",],3)

#### SpCWM.PC2 ####
mbAD1_SpCWM.PC21_data<-interact_plot(mbAD1,pred = DIg1,modx = SpCWM.PC21,data = arid,
                                     modx.values=round(c(min(arid$SpCWM.PC21),mean(arid$SpCWM.PC21),max(arid$SpCWM.PC21)),1),
                                     interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpCWM.PC21),1),round(mean(arid$SpCWM.PC21),1),round(max(arid$SpCWM.PC21),1))
mbAD1_SpCWM.PC21_data[modx_group=="-2.7",":="(modx_group="-2.7 (Min)")] %>% 
  .[modx_group=="0.5",":="(modx_group="0.5 (Mean)")] %>% 
  .[modx_group=="4",":="(modx_group="4.0 (Max)")]
table(mbAD1_SpCWM.PC21_data$modx_group)

mbAD1_SpCWM.PC21_data$modx_group<-factor(mbAD1_SpCWM.PC21_data$modx_group,
                                         levels<-c("4.0 (Max)","0.5 (Mean)","-2.7 (Min)"))#Change order

Grow_DIg_SpCWM.PC2<-ggplot(mbAD1_SpCWM.PC21_data,aes(x=DIg1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=DIg1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("CW",M[PC2])))+
  xlab(expression(paste("DI (unitless)")))+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position="none",
        axis.title.y = element_text(colour = "white"))+
  scale_y_continuous(limits=c(NA,4.7),breaks = c(2.0,3.0,4.0),
                     labels = label_number(accuracy = 0.1))+#to make it show decimals
  ggtitle(expression(atop(paste(CWM[PC2],": ",italic(P)," <0.001,  "),
                          paste(DI %*% CWM[PC2],": ",italic(P)," = 0.249"))))
Grow_DIg_SpCWM.PC2
round(summary(mbAD)$co["SpCWM.PC2",],3)
round(summary(mbAD)$co["DIg:SpCWM.PC2",],3)

#### logFD ####
mbAD1_SpFD1_data<-interact_plot(mbAD1,pred = DIg1,modx = SpFD1,data = arid,
                                modx.values=round(c(min(arid$SpFD1),mean(arid$SpFD1),max(arid$SpFD1)),1),
                                interval = TRUE,vary.lty = F)$data %>% as.data.table()

c(round(min(arid$SpFD1),1),round(mean(arid$SpFD1),1),round(max(arid$SpFD1),1))
mbAD1_SpFD1_data[modx_group=="0",":="(modx_group="0.0 (Min)")] %>% 
  .[modx_group=="0.1",":="(modx_group="0.1 (Mean)")] %>% 
  .[modx_group=="0.3",":="(modx_group="0.3 (Max)")]
table(mbAD1_SpFD1_data$modx_group)

mbAD1_SpFD1_data$modx_group<-factor(mbAD1_SpFD1_data$modx_group,
                                    levels<-c("0.3 (Max)","0.1 (Mean)","0.0 (Min)"))#Change order

Grow_DIg_logFD<-ggplot(mbAD1_SpFD1_data,aes(x=DIg1,y=exp(logAGBGI)-1,col=modx_group,linetype=modx_group))+
  geom_ribbon(aes(x=DIg1,ymin=exp(ymin)-1,ymax=exp(ymax)-1,group=modx_group),fill="royalblue",col=NA,alpha=0.08)+
  geom_line(size=1)+
  scale_linetype_manual(values = c("solid","solid","solid"),guide="none")+
  scale_colour_manual(values=c("salmon1","darkturquoise","mediumpurple1"),
                      name=expression(paste("FD")))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  xlab(expression(paste("DI (unitless)")))+
  theme_classic()+
  theme(plot.title=element_text(size=10),legend.position="none")+
  scale_y_continuous(limits=c(NA,3.3),breaks = c(2.2,2.6,3.0,3.4))+
  ggtitle(expression(atop(paste(FD, ": ", italic(P), " < 0.001,  "),
                          paste(DI %*% FD, ": ", italic(P), " = 0.902"))))

Grow_DIg_logFD
round(summary(mbAD)$co["logFD",],3)
round(summary(mbAD)$co["DIg:logFD",],3)

# Temporal trends in climate drivers --------------------------------------
#### ATA Trend ####
ATA_Y<-ggplot(arid,aes(Year,ATA1))+
  #stat_summary(aes(x=Year,y=ATA1),fun.data = "mean_cl_boot",shape=1,col="turquoise")+
  geom_point(aes(x=Year,y=ATA1),col="turquoise",size=0.1)+
  stat_smooth(color="skyblue3",fill="lightblue",alpha=0.4,size=0.8)+
  stat_smooth(method="lm",formula=y~x,color="royalblue4",size=1.1)+
  theme_classic()+
  labs(x="",y=expression(paste("Temperature anomaly (ATA",~degree*C,")")))+
  theme_classic()+
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 10),
        legend.title.align = 0,
        plot.title = element_text(size = 10, face = "bold"),
        text = element_text(size=11),
        legend.background = element_rect(fill = NA,colour = NA),
        legend.text = element_text(color="grey20"))+
  ggtitle(expression(atop(paste(italic(R)^2," = 0.52,"), paste("Slope = 0.38",~degree~C," ",decade^-1))))
ATA_Y

cor(arid$ATA1,arid$Year)^2
round(summary(lm(ATA1~Year,arid))$coef,3)
r.squaredGLMM(lm(ATA1~Year,arid))

#### DIg Trend ####
DIg_Y<-ggplot(arid, aes(x=Year,y=DIg1))+
  #stat_summary(aes(x=Year,y=DIg1),fun.data = "mean_cl_boot",shape=1,col="turquoise")+
  geom_point(aes(x=Year, y=DIg1),col="turquoise",size=0.1)+
  stat_smooth(color="skyblue3",fill="lightblue",alpha=0.4,size=0.8)+
  stat_smooth(method="lm",formula=y~x,color="royalblue4",size=1.1)+
  theme_classic()+
  labs(x="",y=expression(paste("Drought intensity (DI, unitless)")))+
  theme_classic()+
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 10),
        legend.title.align = 0,
        plot.title = element_text(size = 10, face = "bold"),
        text = element_text(size=10),
        legend.background = element_rect(fill = NA,colour = NA),
        legend.text = element_text(color="grey20"))+
  ggtitle(expression(atop(paste(italic(R)^2," = 0.02,"), paste("Slope = 0.05 DI ",decade^-1))))
DIg_Y

round(cor(arid$DIg1,arid$Year)^2,2)
round(summary(lm(DIg1~Year,arid))$coef,3)
r.squaredGLMM(lm(DIg1~Year,arid))

#### dummy ####
dummy<-ggplot()+
  geom_point(data=arid,aes(x=SpFD1,y=AGBGI),size=0.1,col="white")+
  theme(axis.text.x = element_blank(),axis.text.y = element_blank(),
        axis.line = element_blank(),
        axis.ticks = element_blank(),
        axis.text = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  ylim(0,20)+
  ylab(expression(paste("")))+
  xlab(expression(paste("")))
dummy

#### Bind figures ####
Climate<-ggarrange(ATA_Y,Grow_ATA_logFD,Grow_ATA_SpCWM.PC1,Grow_ATA_SpCWM.PC2,
                   dummy,dummy,dummy,dummy,
                   DIg_Y,Grow_DIg_logFD,Grow_DIg_SpCWM.PC1,Grow_DIg_SpCWM.PC2,
                   labels = c("A","B","C","D",
                              "","","","",
                              "E","F","G","H"),
                   ncol = 4, nrow = 3,
                   heights = c(1.2, 0.1, 1.2),
                   widths = c(1, 1, 1, 1),
                   font.label = list(size = 14))

setwd("~/To Figshare")
ggsave(file="Fig.4_Climate_Interactions_2023-04-28.tiff",
       plot=Climate,dpi=300,width=12,height=7,compression="lzw")

# Fig. S4 -----------------------------------------------------------------
# Ridge Regression --------------------------------------------------------
library(fastDummies)
dat<-arid[,.(DrainCat)]
dat1<-dummy_cols(dat)
arid<-cbind(arid,dat1[,-1])
setnames(arid,names(dat1[,-1]),gsub("DrainCat_","",names(dat1[,-1])))

# Specify the variables for interaction terms
interaction_vars<-c("MATave","AIave","SI","logSA","Y","ATA","DIg","logFD","SpFRed","SpCWM.PC1","SpCWM.PC2")

glmnet.dat<-arid[,.(MATave,AIave,SI,logSA,Y,ATA,DIg,logFD,SpFRed,SpCWM.PC1,SpCWM.PC2)]
# Create interaction terms using a loop
for (var1 in interaction_vars) {
  for (var2 in interaction_vars) {
    if (var1 != var2) {
      interaction_col <- paste0(var1, "_", var2)
      glmnet.dat[, (interaction_col) := get(var1) * get(var2)]
    }
  }
}

# Scale the data
glmnet.dat <- as.data.table(scale(glmnet.dat))

#### lmer ####
mbAD<-lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
             (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
             MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             (1|PLOT_ID),
           control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
           arid)
summary(mbAD)$co

#### logFD mb glm.net ####
glmnet.dat[,":="(Intercept=1,
                 logAGBGI=arid$logAGBGI,
                 PLOT_ID=as.factor(arid$PLOT_ID),
                 DrainCat=as.factor(arid$DrainCat),
                 Moderately=arid$Moderately,Poorly=arid$Poorly,Well=arid$Well,
                 wi=arid$wi)]#Add these after scaling

mod_mbAD<-lmer(logAGBGI~
                 (ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                 (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
                 MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                 AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                 SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                 logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                 (1|PLOT_ID),
               control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
               arid)
summary(mod_mbAD)$co

glmnet.dat[,":="(ran1AD=ranef(mod_mbAD)$PLOT_ID[match(arid$PLOT_ID,row.names(ranef(mod_mbAD)$PLOT_ID)),])] %>% 
  .[,":="(logAGBGI_corr=logAGBGI-ran1AD)]

summary(lm(logAGBGI_corr~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
             (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
             MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
             logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2),
           glmnet.dat))$coef
summary(mod_mbAD)$coef#pretty much comparable

## glmnet ##
#Below, doesn't run with x = categorical vars; use converted dummy numeric fixed vars
lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(#Moderately,Poorly,Well,
    MATave,AIave,SI,logSA,ATA,
    DIg,logFD,SpCWM.PC1,SpCWM.PC2,MATave_ATA,MATave_DIg,
    MATave_logFD,MATave_SpCWM.PC1,MATave_SpCWM.PC2,AIave_ATA,AIave_DIg,AIave_logFD,AIave_SpCWM.PC1,
    AIave_SpCWM.PC2,SI_ATA,SI_DIg,SI_logFD,SI_SpCWM.PC1,SI_SpCWM.PC2,logSA_ATA,
    logSA_DIg,logSA_logFD,logSA_SpCWM.PC1,logSA_SpCWM.PC2,ATA_logFD,ATA_SpCWM.PC1,ATA_SpCWM.PC2,
    DIg_logFD,DIg_SpCWM.PC1,DIg_SpCWM.PC2)]),
  y=as.matrix(glmnet.dat[,logAGBGI_corr]),#weights=as.vector(glmnet.dat[,wi])
)$lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

#glmnet
#In glmnet, it automatically converts categorical to binomial dummies
gl.mb<-glmnet(logAGBGI_corr~#Moderately+Poorly+Well+
                ATA+DIg+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                ATA_logFD+ATA_SpCWM.PC1+ATA_SpCWM.PC2+DIg_logFD+DIg_SpCWM.PC1+DIg_SpCWM.PC2+
                MATave_ATA+MATave_DIg+
                MATave_logFD+MATave_SpCWM.PC1+MATave_SpCWM.PC2+AIave_ATA+AIave_DIg+AIave_logFD+AIave_SpCWM.PC1+
                AIave_SpCWM.PC2+SI_ATA+SI_DIg+SI_logFD+SI_SpCWM.PC1+SI_SpCWM.PC2+logSA_ATA+
                logSA_DIg+logSA_logFD+logSA_SpCWM.PC1+logSA_SpCWM.PC2,
              data=glmnet.dat,
              lambda=lambda_values,#covers range of no suppression to max of 1se
              alpha=0)#0=ridge regression

#### bootstrap [lambda=1se] ########
coeff.se.glmnet.mb<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,PLOT_ID]),replace=TRUE)
  newdat<-glmnet.dat[PLOT_ID%in%too_boot]
  
  lmerboot<-(lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                    (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
                    MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                    AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                    SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                    logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                    (1|PLOT_ID),
                  control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                  data=newdat))
  
  newdat[,":="(ran1AD=ranef(lmerboot)$PLOT_ID[match(newdat$PLOT_ID,row.names(ranef(lmerboot)$PLOT_ID)),])] %>% 
    .[,":="(logAGBGI_corr=logAGBGI-ran1AD)]
  
  gl.mb2<-glmnet(logAGBGI_corr~#Moderately+Poorly+Well+
                   ATA+DIg+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                   ATA_logFD+ATA_SpCWM.PC1+ATA_SpCWM.PC2+DIg_logFD+DIg_SpCWM.PC1+DIg_SpCWM.PC2+
                   MATave_ATA+MATave_DIg+
                   MATave_logFD+MATave_SpCWM.PC1+MATave_SpCWM.PC2+AIave_ATA+AIave_DIg+AIave_logFD+AIave_SpCWM.PC1+
                   AIave_SpCWM.PC2+SI_ATA+SI_DIg+SI_logFD+SI_SpCWM.PC1+SI_SpCWM.PC2+logSA_ATA+
                   logSA_DIg+logSA_logFD+logSA_SpCWM.PC1+logSA_SpCWM.PC2,
                 data=newdat,
                 lambda=lambda_values,#covers range of no suppression to max of 1se
                 alpha=0)
  output<-coef(gl.mb2)
  #output<-output[-c(grep('Eco',row.names(output))),]
  output@x
},.progress="win"
) %>% as.data.table #18:50 takes 20 min

setwd("~/To Figshare")
#save(coeff.se.glmnet.mb,file="mod_mbAD_Ridge_regression_coeff.1se.Grow.R")
load("mod_mbAD_Ridge_regression_coeff.1se.Grow.R")

colnames(coeff.se.glmnet.mb)<-rep(c("Int",
                                    "ATA","DIg","logFD","SpCWM.PC1","SpCWM.PC2","MATave","AIave","SI","logSA",
                                    "ATA_logFD","ATA_SpCWM.PC1","ATA_SpCWM.PC2","DIg_logFD","DIg_SpCWM.PC1","DIg_SpCWM.PC2",
                                    "MATave_ATA","MATave_DIg",
                                    "MATave_logFD","MATave_SpCWM.PC1","MATave_SpCWM.PC2","AIave_ATA","AIave_DIg","AIave_logFD","AIave_SpCWM.PC1",
                                    "AIave_SpCWM.PC2","SI_ATA","SI_DIg","SI_logFD","SI_SpCWM.PC1","SI_SpCWM.PC2","logSA_ATA",
                                    "logSA_DIg","logSA_logFD","logSA_SpCWM.PC1","logSA_SpCWM.PC2"),
                                  ncol(coeff.se.glmnet.mb)/(length(fixef(mbAD))))#Add +1 for the Intercept, as well as mod, well, poor

coeff.se.glmnet.mb_tidy<-data.table(
  Int=unlist(apply(coeff.se.glmnet.mb[,grep("^Int$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  ATA=unlist(apply(coeff.se.glmnet.mb[,grep("^ATA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  DIg=unlist(apply(coeff.se.glmnet.mb[,grep("^DIg$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  MATave=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  AIave=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI=unlist(apply(coeff.se.glmnet.mb[,grep("^SI$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  ATA_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^ATA_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  ATA_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^ATA_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  ATA_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^ATA_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  DIg_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^DIg_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  DIg_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^DIg_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  DIg_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^DIg_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  MATave_ATA=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave_ATA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  MATave_DIg=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave_DIg$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  MATave_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  MATave_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  MATave_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^MATave_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  AIave_ATA=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave_ATA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  AIave_DIg=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave_DIg$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  AIave_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  AIave_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  AIave_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^AIave_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  SI_ATA=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_ATA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI_DIg=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_DIg$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI_Y=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_Y$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  SI_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^SI_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  
  logSA_ATA=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_ATA$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA_DIg=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_DIg$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA_Y=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_Y$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA_logFD=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_logFD$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA_SpCWM.PC1=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_SpCWM.PC1$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list)),
  logSA_SpCWM.PC2=unlist(apply(coeff.se.glmnet.mb[,grep("^logSA_SpCWM.PC2$",colnames(coeff.se.glmnet.mb)),with=FALSE],2,list))
)

Ridge.mb.T_1se<-data.table(Source=names(fixef(mbAD)),
                           mean.Grow=NA,up.Grow=NA,low.Grow=NA)

Ridge.mb.T_1se$mean.Grow<-apply(coeff.se.glmnet.mb_tidy,2,mean)
Ridge.mb.T_1se$up.Grow<-apply(coeff.se.glmnet.mb_tidy,2,function(x){quantile(x,0.975)})
Ridge.mb.T_1se$low.Grow<-apply(coeff.se.glmnet.mb_tidy,2,function(x){quantile(x,0.025)})
Ridge.mb.T_1se$Model<-"Ridge regression"

#### Prepare for Graph mbAD ####
#### Simultaneous ####
OrgT_mbAD<-data.table(Source=names(fixef(mbAD)),
                      mean.Grow=NA,up.Grow=NA,low.Grow=NA)
OrgT_mbAD[,":="(mean.Grow=summary(mbAD)$co[,1],
                up.Grow=summary(mbAD)$co[,1]+summary(mbAD)$co[,2]*1.96,
                low.Grow=summary(mbAD)$co[,1]-summary(mbAD)$co[,2]*1.96,
                Model="Linear mixed model")]

#### Sequential modelling ####
round(cor(arid[,.(Year,ATA1,DIg1)]),2)

#Prioritizing DIg
mbADseqDIg1<-lmer(logAGBGI~DIg+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                    DIg:(logFD+SpCWM.PC1+SpCWM.PC2)+
                    MATave:(DIg+logFD+SpCWM.PC1+SpCWM.PC2)+
                    AIave:(DIg+logFD+SpCWM.PC1+SpCWM.PC2)+
                    SI:(DIg+logFD+SpCWM.PC1+SpCWM.PC2)+
                    logSA:(DIg+logFD+SpCWM.PC1+SpCWM.PC2)+
                    (1|PLOT_ID),
                  control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                  arid)
summary(mbADseqDIg1)$co

mbADseqDIg2<-lm(resid(mbADseqDIg1)~ATA+
                  ATA:(logFD+SpCWM.PC1+SpCWM.PC2)+
                  MATave:ATA+
                  AIave:ATA+
                  SI:ATA+
                  logSA:ATA,
                arid)
summary(mbADseqDIg2)$coef

T_mbADseqDIg<-data.table(Source=c(names(fixef(mbADseqDIg1)[-1]),names(coef(mbADseqDIg2)[-1])),
                         mean.Grow=NA,up.Grow=NA,low.Grow=NA)
T_mbADseqDIg[,":="(mean.Grow=c(summary(mbADseqDIg1)$coef[-1,1],summary(mbADseqDIg2)$coef[-1,1]),
                   up.Grow=c((summary(mbADseqDIg1)$coef[-1,1]+summary(mbADseqDIg1)$coef[-1,2]*1.96),
                             (summary(mbADseqDIg2)$coef[-1,1]+summary(mbADseqDIg2)$coef[-1,2]*1.96)),
                   low.Grow=c((summary(mbADseqDIg1)$coef[-1,1]-summary(mbADseqDIg1)$coef[-1,2]*1.96),
                              (summary(mbADseqDIg2)$coef[-1,1]-summary(mbADseqDIg2)$coef[-1,2]*1.96)),
                   Model="Sequential model (prioritising DI)")]

names_level<-OrgT_mbAD$Source[-1]
T_mbADseqDIg[-which(Source%in%names_level)]#check, still changed order

T_mbADseqDIg$Source<-factor(T_mbADseqDIg$Source,levels=names_level)
T_mbADseqDIg<-T_mbADseqDIg[order(T_mbADseqDIg$Source)]

#Prioritizing ATA
mbADseqATA1<-lmer(logAGBGI~ATA+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                    ATA:(logFD+SpCWM.PC1+SpCWM.PC2)+
                    MATave:(ATA+logFD+SpCWM.PC1+SpCWM.PC2)+
                    AIave:(ATA+logFD+SpCWM.PC1+SpCWM.PC2)+
                    SI:(ATA+logFD+SpCWM.PC1+SpCWM.PC2)+
                    logSA:(ATA+logFD+SpCWM.PC1+SpCWM.PC2)+
                    (1|PLOT_ID),
                  control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                  arid)
summary(mbADseqATA1)$co

mbADseqATA2<-lm(resid(mbADseqATA1)~DIg+
                  DIg:(logFD+SpCWM.PC1+SpCWM.PC2)+
                  MATave:DIg+
                  AIave:DIg+
                  SI:DIg+
                  logSA:DIg,
                arid)
summary(mbADseqATA2)$coef

T_mbADseqATA<-data.table(Source=c(names(fixef(mbADseqATA1)[-1]),names(coef(mbADseqATA2)[-1])),
                         mean.Grow=NA,up.Grow=NA,low.Grow=NA)
T_mbADseqATA[,":="(mean.Grow=c(summary(mbADseqATA1)$coef[-1,1],summary(mbADseqATA2)$coef[-1,1]),
                   up.Grow=c((summary(mbADseqATA1)$coef[-1,1]+summary(mbADseqATA1)$coef[-1,2]*1.96),
                             (summary(mbADseqATA2)$coef[-1,1]+summary(mbADseqATA2)$coef[-1,2]*1.96)),
                   low.Grow=c((summary(mbADseqATA1)$coef[-1,1]-summary(mbADseqATA1)$coef[-1,2]*1.96),
                              (summary(mbADseqATA2)$coef[-1,1]-summary(mbADseqATA2)$coef[-1,2]*1.96)),
                   Model="Sequential model (prioritising ATA)")]

names_level<-OrgT_mbAD$Source[-1]
T_mbADseqATA[-which(Source%in%names_level)]#check, still changed order

T_mbADseqATA$Source<-factor(T_mbADseqATA$Source,levels=names_level)
T_mbADseqATA<-T_mbADseqATA[order(T_mbADseqATA$Source)]

#### Bind for Figures mbAD ####
to_gg.mbAD.all<-rbind(OrgT_mbAD[-1],
                      T_mbADseqATA,
                      T_mbADseqDIg,
                      Ridge.mb.T_1se[-1])

to_gg.mbAD.all[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("DIg","DI",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

nr<-nrow(to_gg.mbAD.all)/4#number of models comparing
names_level<-to_gg.mbAD.all[1:nr,Source]
to_gg.mbAD.all$Source<-factor(to_gg.mbAD.all$Source,levels=rev(names_level))

to_gg.mbAD.all$Model<-factor(to_gg.mbAD.all$Model,
                             levels=c("Linear mixed model",
                               "Sequential model (prioritising ATA)",
                               "Sequential model (prioritising DI)",
                               "Ridge regression"))

Grow.mbAD.all<-ggplot(to_gg.mbAD.all,aes(x=mean.Grow,xmin=low.Grow,xmax=up.Grow,y=Source,col=Model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(position=position_dodge(0.7),size=2)+
  geom_errorbar(position=position_dodge(0.7),width=0)+
  scale_colour_manual(values=c("brown1","forestgreen","goldenrod","dodgerblue","purple"))+
  theme_bw()+
  theme(#panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    legend.position="none",
    axis.text.x=element_text(size=10),
    axis.text.y=element_text(size=10))+
  #theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+
  ylab("")+
  scale_y_discrete(labels = scales::parse_format())+
  theme(legend.title=element_text(size=11),
        legend.text=element_text(size=10),
        axis.text.y = element_text(size=12),
        axis.text.x = element_text(size=12),
        legend.position=c(0.22,0.2),
        legend.background=element_rect(fill="aliceblue",color=NA))
Grow.mbAD.all

#### Bind Figures ####
Grow_save_multicol<-ggarrange(Grow.mbAD.all,
                              ncol = 1, nrow = 1,
                              font.label = list(size = 12))

ggsave(file="Fig.S_Multicollinearity_effect_size_Ridge_Sequential.tiff",
       plot=Grow_save_multicol,dpi=300,width=8,height=10,compression="lzw")

# Fig. S3 -----------------------------------------------------------------
#### Prepare for Graph mb ####
SI_mb<-data.table(Source=names(fixef(mb)),
                  mean.Grow=NA,up.Grow=NA,low.Grow=NA)
SI_mb[,":="(mean.Grow=summary(mb)$co[,1],
            up.Grow=summary(mb)$co[,1]+summary(mb)$co[,2]*1.96,
            low.Grow=summary(mb)$co[,1]-summary(mb)$co[,2]*1.96,
            Model="Original model with site index")]

SI_mb[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("Y","Year",Source))] %>% 
  .[,":="(Source=gsub("SI","SI[or]*Drain",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

#### Modelling with Soil Drainage Class
mb.SD<-lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+logDrainNum+logSA+
              Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
              MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              logDrainNum:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              (1|PLOT_ID),
            control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
            arid)
summary(mb.SD)$co

SD_mb<-data.table(Source=names(fixef(mb.SD)[-1]),
                  mean.Grow=NA,up.Grow=NA,low.Grow=NA)
SD_mb[,":="(mean.Grow=summary(mb.SD)$coef[-1,1],
            up.Grow=summary(mb.SD)$coef[-1,1]+summary(mb.SD)$coef[-1,2]*1.96,
            low.Grow=summary(mb.SD)$coef[-1,1]-summary(mb.SD)$coef[-1,2]*1.96,
            Model="Modelling with soil drainage class")]

SD_mb[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("Y","Year",Source))] %>% 
  .[,":="(Source=gsub("DrainNum","SI[or]*Drain",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

#### Bind for Figures mb ####
to_gg.mb.SISD<-rbind(SI_mb[-1],
                     SD_mb)

to_gg.mb.SISD

nr<-nrow(to_gg.mb.SISD)/2#number of models comparing
names_level<-to_gg.mb.SISD[1:nr,Source]
to_gg.mb.SISD$Source<-factor(to_gg.mb.SISD$Source,levels=rev(names_level))

to_gg.mb.SISD$Model<-factor(to_gg.mb.SISD$Model,
                            levels=(c("Original model with site index",
                                      "Modelling with soil drainage class")))

Grow.mb.SISD<-ggplot(to_gg.mb.SISD,aes(x=mean.Grow,xmin=low.Grow,xmax=up.Grow,y=Source,col=Model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(position=position_dodge(0.7),size=2)+
  geom_errorbar(position=position_dodge(0.7),width=0)+
  theme_bw()+
  theme(#panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    legend.position="none",
    axis.text.x=element_text(size=10),
    axis.text.y=element_text(size=10))+
  #theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+
  ylab("")+
  scale_y_discrete(labels = scales::parse_format())+
  theme(legend.title=element_text(size=11),
        legend.text=element_text(size=10),
        legend.position="none",
        legend.background=element_rect(fill="aliceblue",color=NA))
Grow.mb.SISD

#### Prepare for Graph mbAD ####
SI_mbAD<-data.table(Source=names(fixef(mbAD)),
                    mean.Grow=NA,up.Grow=NA,low.Grow=NA)
SI_mbAD[,":="(mean.Grow=summary(mbAD)$co[,1],
              up.Grow=summary(mbAD)$co[,1]+summary(mbAD)$co[,2]*1.96,
              low.Grow=summary(mbAD)$co[,1]-summary(mbAD)$co[,2]*1.96,
              Model="Original model with site index")]

SI_mbAD[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("DIg","DI",Source))] %>% 
  .[,":="(Source=gsub("SI","SI[or]*Drain",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

#### Modelling with Soil Drainage Class
mbAD.SD<-lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+logDrainNum+logSA+
                (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
                MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                logDrainNum:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                (1|PLOT_ID),
              control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
              arid)
summary(mbAD.SD)$co

SD_mbAD<-data.table(Source=names(fixef(mbAD.SD)[-1]),
                    mean.Grow=NA,up.Grow=NA,low.Grow=NA)
SD_mbAD[,":="(mean.Grow=summary(mbAD.SD)$coef[-1,1],
              up.Grow=summary(mbAD.SD)$coef[-1,1]+summary(mbAD.SD)$coef[-1,2]*1.96,
              low.Grow=summary(mbAD.SD)$coef[-1,1]-summary(mbAD.SD)$coef[-1,2]*1.96,
              Model="Modelling with soil drainage class")]

SD_mbAD[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("DIg","DI",Source))] %>% 
  .[,":="(Source=gsub("DrainNum","SI[or]*Drain",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

#### Bind for Figures mbAD ####
to_gg.mbAD.SISD<-rbind(SI_mbAD[-1],
                       SD_mbAD)

to_gg.mbAD.SISD

nr<-nrow(to_gg.mbAD.SISD)/2#number of models comparing
names_level<-to_gg.mbAD.SISD[1:nr,Source]
to_gg.mbAD.SISD$Source<-factor(to_gg.mbAD.SISD$Source,levels=rev(names_level))

to_gg.mbAD.SISD$Model<-factor(to_gg.mbAD.SISD$Model,
                              levels=(c("Original model with site index",
                                        "Modelling with soil drainage class")))

Grow.mbAD.SISD<-ggplot(to_gg.mbAD.SISD,aes(x=mean.Grow,xmin=low.Grow,xmax=up.Grow,y=Source,col=Model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(position=position_dodge(0.7),size=2)+
  geom_errorbar(position=position_dodge(0.7),width=0)+
  theme_bw()+
  theme(#panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    legend.position="none",
    axis.text.x=element_text(size=10),
    axis.text.y=element_text(size=10))+
  #theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+
  ylab("")+
  scale_y_discrete(labels = scales::parse_format())+
  theme(legend.title=element_text(size=11),
        legend.text=element_text(size=10),
        legend.position=c(0.25,0.65),
        legend.background=element_rect(fill="aliceblue",color=NA))
Grow.mbAD.SISD

#### Bind Figures ####
Grow_save_SISD<-ggarrange(Grow.mb.SISD,Grow.mbAD.SISD,
                          ncol = 2, nrow = 1,
                          labels = c("A","B"),
                          widths=c(0.45,0.55),
                          font.label = list(size = 13))

ggsave(file="Fig.S_Compare_SI_and_SoilDrain.tiff",
       plot=Grow_save_SISD,dpi=300,width=13,height=7,compression="lzw")

# Fig. S5 -----------------------------------------------------------------
#Based on:
#https://cmdlinetips.com/2019/07/how-to-randomly-select-groups-in-r-with-dplyr/
sample_n_groups = function(grouped_df, size, replace = FALSE, weight=NULL) {
  grp_var <- grouped_df %>% 
    groups %>%
    unlist %>% 
    as.character
  random_grp <- grouped_df %>% 
    summarise() %>% 
    sample_n(size, replace, weight) %>% 
    mutate(unique_id = 1:NROW(.))
  grouped_df %>% 
    right_join(random_grp, by=grp_var) %>% 
    group_by_(grp_var)
  #group_by(!!as.name(grp_var))
} 
#lifecycle::last_lifecycle_warnings() #to see the warning again

mb<-lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
           Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
           MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
           (1|PLOT_ID),
         control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
         arid)

dat<-arid[,.(PLOT_ID,PLOT_MS,Eco,Prov,logAGBGI,
             DrainCat,MATave1,AIave1,SI1,logSA1,
             Year,ATA1,DIg1,
             logFD1,SpFRed1,SpCWM.PC11,SpCWM.PC21,
             PS,TL)]#get unscaled vars - scale them later during the random sampling

# -------------------------------------------------------------------------
newdat<-dat %>% group_by(PLOT_ID) %>% sample_n_groups(round(length(unique(arid$PLOT_ID))*0.1)) %>% data.table()

newdat<-newdat[,":="(MATave=scale(MATave1),
                     AIave=scale(AIave1),
                     SI=scale(SI1),
                     logSA=scale(logSA1),Y=scale(Year),
                     logFD=scale(logFD1),SpFRed=scale(SpFRed1),
                     SpCWM.PC1=scale(SpCWM.PC11),SpCWM.PC2=scale(SpCWM.PC21),
                     logPS_TL=PS^.5*TL)] %>% 
  .[,":="(wi=logPS_TL/max(logPS_TL))]

fit <- lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
              Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
              MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
              (1|PLOT_ID),
            control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
            newdat)

summary(fit)$co[c("Y","logFD","Y:logFD"),]
table(newdat$Prov)

# Determine sample size -------------------------------------------------------------------------
#https://note.com/dd_techblog/n/n73eca35106c7
#Cohen's h
#This below is to just calculate df
df_n<-nrow(arid)-(length(unique(arid$PLOT_ID))+(length(fixef(mb))-1)+1)

# Sample size for multilevel model with 3774 cluster groups 
# and a medium to large effect size for linear models of 0.3
# A total sample size of about 3898 observations is needed.
samplesize_mixed(eff.size = 0.3,
                 df.n = df_n,
                 power = 0.8,
                 sig.level = 0.05,
                 k = length(unique(arid$PLOT_ID)),
                 icc = 0.05)$`Total Sample Size`

(newdat<-dat %>% group_by(PLOT_ID) %>% sample_n_groups(1600) %>% data.table())#1600 can work for approx 2900 Obs

##### #### ##### #### NO NEED TO RUN (to get mean and CIs for the Suppl Meth) ##### #### ##### ####
nrow((newdat<-dat %>% group_by(PLOT_ID) %>% sample_n_groups(1600) %>% data.table()))
# Create an empty list to store the results
result <- vector()

# Set the number of iterations
n_iter <- 1000

# Run the loop
for (i in 1:n_iter) {
  # Perform the sampling and save the result to the list
  result[[i]] <- nrow(dat %>% group_by(PLOT_ID) %>% sample_n_groups(1600)) %>% as.numeric()
}

# Calculate the mean and 95% CI for each column of the sampled data
(means <- mean(result))
(cis <- c(quantile(result,0.025),quantile(result,0.975)))
(range <- c(min(result),max(result)))
##### ##### ##### #### ##### #### ##### #### ##### #### #####

set.seed(42)
rep=1000

#### logFD Year model ####
f3000FD <- function () {
  newdat<-dat %>% group_by(PLOT_ID) %>% sample_n_groups(1600) %>% data.table()
  
  newdat<-newdat[,":="(MATave=scale(MATave1),
                       AIave=scale(AIave1),
                       SI=scale(SI1),
                       logSA=scale(logSA1),Y=scale(Year),
                       logFD=scale(logFD1),
                       SpCWM.PC1=scale(SpCWM.PC11),SpCWM.PC2=scale(SpCWM.PC21),
                       logPS_TL=PS^.5*TL)] #%>% 
  #.[,":="(wi=logPS_TL/max(logPS_TL))]
  
  fit <- lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
                MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                (1|PLOT_ID),
              control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
              newdat)
  
  summary(fit)$coef[c("Y","logFD","SpCWM.PC1","SpCWM.PC2","MATave","AIave","SI",
                      "logSA","Y:logFD","Y:SpCWM.PC1","Y:SpCWM.PC2","Y:MATave","logFD:MATave","SpCWM.PC1:MATave","SpCWM.PC2:MATave",
                      "Y:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave","Y:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI",
                      "Y:logSA","logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA"),1]
}

#set.seed(0); z3000FD <- t(replicate(rep, f3000FD()))#run #18:27
#save(z3000FD,file="z3000FD.R")
load("z3000FD.R")

## Get the coefs
coef.se<-unlist(z3000FD) %>% data.table()
summary(coef.se)

RandomT_mb<-data.table(Source=names(fixef(mb)[c("Y","logFD","SpCWM.PC1","SpCWM.PC2","MATave","AIave","SI",
                                                "logSA","Y:logFD","Y:SpCWM.PC1","Y:SpCWM.PC2","Y:MATave","logFD:MATave","SpCWM.PC1:MATave","SpCWM.PC2:MATave",
                                                "Y:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave","Y:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI",
                                                "Y:logSA","logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA")]),
                       mean.Grow=NA,up.Grow=NA,low.Grow=NA)

RandomT_mb[,":="(mean.Grow=apply(coef.se,2,mean),
                 up.Grow=apply(coef.se,2,function(x){quantile(x,0.975)}),
                 low.Grow=apply(coef.se,2,function(x){quantile(x,0.025)}))]

RandomT_mb$Source<-factor(RandomT_mb$Source,
                          levels=names(fixef(mb)[c("Y","logFD","SpCWM.PC1","SpCWM.PC2","MATave","AIave","SI",
                                                   "logSA","Y:logFD","Y:SpCWM.PC1","Y:SpCWM.PC2","Y:MATave","logFD:MATave","SpCWM.PC1:MATave","SpCWM.PC2:MATave",
                                                   "Y:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave","Y:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI",
                                                   "Y:logSA","logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA")]))

RandomT_mb[,":="(Model="Random sampling")]

# -------------------------------------------------------------------------
df_n.AD<-nrow(arid)-(length(unique(arid$PLOT_ID))+(length(fixef(mbAD))-1)+1)

# Sample size for multilevel model with 3774 cluster groups 
# and a medium to large effect size for linear models of 0.3
# A total sample size of about 2805 observations is needed.
samplesize_mixed(eff.size = 0.3,
                 df.n = df_n.AD,
                 power = 0.8,
                 sig.level = 0.05,
                 k = length(unique(arid$PLOT_ID)),
                 icc = 0.05)$`Total Sample Size`

#### logFD Climate model ####
f3000AD.FD <- function () {
  newdat<-dat %>% group_by(PLOT_ID) %>% sample_n_groups(1600) %>% data.table()
  
  newdat<-newdat[,":="(MATave=scale(MATave1),
                       AIave=scale(AIave1),
                       SI=scale(SI1),
                       logSA=scale(logSA1),
                       Y=scale(Year),ATA=scale(ATA1),DIg=scale(DIg1),
                       logFD=scale(logFD1),
                       SpCWM.PC2=scale(SpCWM.PC21),SpCWM.PC1=scale(SpCWM.PC11),
                       logPS_TL=PS^.5*TL)]%>% 
    .[,":="(wi=logPS_TL/max(logPS_TL))]
  
  fit <- lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
                MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                (1|PLOT_ID),
              control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
              newdat)
  
  summary(fit)$coef[c("ATA","DIg","logFD","SpCWM.PC1","SpCWM.PC2","MATave",
                      "AIave","SI","logSA","ATA:logFD","ATA:SpCWM.PC1","ATA:SpCWM.PC2","DIg:logFD","DIg:SpCWM.PC1",
                      "DIg:SpCWM.PC2","ATA:MATave","DIg:MATave","logFD:MATave",
                      "SpCWM.PC1:MATave","SpCWM.PC2:MATave","ATA:AIave","DIg:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave",
                      "ATA:SI","DIg:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI","ATA:logSA","DIg:logSA",
                      "logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA"),1]
}

#set.seed(0); z3000AD.FD <- t(replicate(rep, f3000AD.FD()))#run #just 10 min
#save(z3000AD.FD,file="z3000AD.FD.R")
load("z3000AD.FD.R")

## Get the coefs
coef.se<-unlist(z3000AD.FD) %>% data.table()
summary(coef.se)

RandomT_mbAD<-data.table(Source=names(fixef(mbAD)[c("ATA","DIg","logFD","SpCWM.PC1","SpCWM.PC2","MATave",
                                                    "AIave","SI","logSA","ATA:logFD","ATA:SpCWM.PC1","ATA:SpCWM.PC2","DIg:logFD","DIg:SpCWM.PC1",
                                                    "DIg:SpCWM.PC2","ATA:MATave","DIg:MATave","logFD:MATave",
                                                    "SpCWM.PC1:MATave","SpCWM.PC2:MATave","ATA:AIave","DIg:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave",
                                                    "ATA:SI","DIg:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI","ATA:logSA","DIg:logSA",
                                                    "logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA")]),
                         mean.Grow=NA,up.Grow=NA,low.Grow=NA)

RandomT_mbAD[,":="(mean.Grow=apply(coef.se,2,mean),
                   up.Grow=apply(coef.se,2,function(x){quantile(x,0.975)}),
                   low.Grow=apply(coef.se,2,function(x){quantile(x,0.025)}))]

RandomT_mbAD$Source<-factor(RandomT_mbAD$Source,
                            levels=names(fixef(mbAD)[c("ATA","DIg","logFD","SpCWM.PC1","SpCWM.PC2","MATave",
                                                       "AIave","SI","logSA","ATA:logFD","ATA:SpCWM.PC1","ATA:SpCWM.PC2","DIg:logFD","DIg:SpCWM.PC1",
                                                       "DIg:SpCWM.PC2","ATA:MATave","DIg:MATave","logFD:MATave",
                                                       "SpCWM.PC1:MATave","SpCWM.PC2:MATave","ATA:AIave","DIg:AIave","logFD:AIave","SpCWM.PC1:AIave","SpCWM.PC2:AIave",
                                                       "ATA:SI","DIg:SI","logFD:SI","SpCWM.PC1:SI","SpCWM.PC2:SI","ATA:logSA","DIg:logSA",
                                                       "logFD:logSA","SpCWM.PC1:logSA","SpCWM.PC2:logSA")]))

RandomT_mbAD[,":="(Model="Random sampling")]

# Core data (similar to Brienen 2015) -----------------------------------------------------------------
arid[,":="(maxY1=max(FinY),
           minY1=min(IniY),
           meanY1=mean(Year)),
     by=PLOT_ID] %>% 
  .[,":="(total_Length=maxY1-minY1),by=PLOT_ID]

check<-seq(1958,2015,by=1)
summary(check)

arid<-arid[,":="(Census=row_number(FinY),
                 Censuses=length(FinY)),by=PLOT_ID] %>% 
  .[,":="(Census=Census+1,
          Censuses=Censuses+1)]

## Plot Refinements Criteria
summary(arid$total_Length)
coredat<-arid[Censuses>=2&total_Length>=20] #%>% #Monitored more than twice with more than 20 years (i.e., 1st quantile of TL)
length(unique(coredat$PLOT_ID))#1579 plots left
table(coredat$Prov)

coredat[,":="(MATave=scale(MATave1),
              AIave=scale(AIave1),
              SI=scale(SI1),
              logSA=scale(logSA1),
              Y=scale(Year),ATA=scale(ATA1),DIg=scale(DIg1),
              logFD=scale(logFD1),
              SpCWM.PC1=scale(SpCWM.PC11),
              SpCWM.PC2=scale(SpCWM.PC21),
              logPS_TL=PS^.5*TL)]%>% 
  .[,":="(wi=logPS_TL/max(logPS_TL))]

#### logFD Year model ####
mb.core<-lmer(logAGBGI~Y+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                Y:(logFD+SpCWM.PC1+SpCWM.PC2)+
                MATave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                AIave:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                SI:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                logSA:(Y+logFD+SpCWM.PC1+SpCWM.PC2)+
                (1|PLOT_ID),
              control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
              coredat)

summary(mb.core)$co

coefmean<-summary(mb.core)$co[,1]
coefSEup<-summary(mb.core)$co[,1]+summary(mb.core)$co[,2]*1.96
coefSElow<-summary(mb.core)$co[,1]-summary(mb.core)$co[,2]*1.96

Core_mb_T<-data.table(Source=names(fixef(mb.core)),
                      mean.Grow=NA,up.Grow=NA,low.Grow=NA)

Core_mb_T[,":="(mean.Grow=summary(mb.core)$co[,1],
                up.Grow=summary(mb.core)$co[,1]+summary(mb.core)$co[,2]*1.96,
                low.Grow=summary(mb.core)$co[,1]-summary(mb.core)$co[,2]*1.96,
                Model="Subset (≥20 yrs)")]

#### logFD Climate model ####
mbAD.core<-lmer(logAGBGI~(ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                  (ATA+DIg):(logFD+SpCWM.PC1+SpCWM.PC2)+
                  MATave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                  AIave:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                  SI:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                  logSA:((ATA+DIg)+logFD+SpCWM.PC1+SpCWM.PC2)+
                  (1|PLOT_ID),
                control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                coredat)

summary(mbAD.core)$co

coefmean<-summary(mbAD.core)$co[,1]
coefSEup<-summary(mbAD.core)$co[,1]+summary(mbAD.core)$co[,2]*1.96
coefSElow<-summary(mbAD.core)$co[,1]-summary(mbAD.core)$co[,2]*1.96

Core_mbAD_T<-data.table(Source=names(fixef(mbAD.core)),
                        mean.Grow=NA,up.Grow=NA,low.Grow=NA)

Core_mbAD_T[,":="(mean.Grow=summary(mbAD.core)$co[,1],
                  up.Grow=summary(mbAD.core)$co[,1]+summary(mbAD.core)$co[,2]*1.96,
                  low.Grow=summary(mbAD.core)$co[,1]-summary(mbAD.core)$co[,2]*1.96,
                  Model="Subset (≥20 yrs)")]

#### Bind and Change Names ####
## Graph mb
OrgT_mb<-data.table(Source=names(fixef(mb)),
                    mean.Grow=NA,up.Grow=NA,low.Grow=NA)

OrgT_mb[,":="(mean.Grow=summary(mb)$co[,1],
              up.Grow=summary(mb)$co[,1]+summary(mb)$co[,2]*1.96,
              low.Grow=summary(mb)$co[,1]-summary(mb)$co[,2]*1.96,
              Model="Full dataset")]

to_gg.mb<-rbind(OrgT_mb[-1],#remove Intercept
                RandomT_mb,
                Core_mb_T[-1])#Change "12", according to the pattern in random sampling (the num of Eco depends on random sampling)

to_gg.mb[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("DrainCat","Drain",Source))] %>% 
  .[,":="(Source=gsub("Y","Year",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))]

nr<-nrow(to_gg.mb)/3
names_level<-to_gg.mb[1:nr,Source]
to_gg.mb$Source<-factor(to_gg.mb$Source,levels=rev(names_level))

to_gg.mb$Model<-factor(to_gg.mb$Model,
                       levels=(c("Full dataset",
                                 "Random sampling",
                                 "Subset (≥20 yrs)")))

Grow.mb<-ggplot(to_gg.mb,aes(x=mean.Grow,xmin=low.Grow,xmax=up.Grow,y=Source,col=Model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(position=position_dodge(0.7),size=1.5)+
  geom_errorbar(position=position_dodge(0.7),width=0)+
  theme_bw()+
  theme(#panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    legend.position="none",
    axis.text.x=element_text(size=9),
    axis.text.y=element_text(size=9),
    axis.title.x = element_text(colour = "white"))+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+
  ylab("")+
  scale_y_discrete(labels = scales::parse_format())#to show the text within []
Grow.mb

## Graph mbAD
OrgT_mbAD<-data.table(Source=names(fixef(mbAD)),
                      mean.Grow=NA,up.Grow=NA,low.Grow=NA)

OrgT_mbAD[,":="(mean.Grow=summary(mbAD)$co[,1],
                up.Grow=summary(mbAD)$co[,1]+summary(mbAD)$co[,2]*1.96,
                low.Grow=summary(mbAD)$co[,1]-summary(mbAD)$co[,2]*1.96,
                Model="Full dataset")]

to_gg.mbAD<-rbind(OrgT_mbAD[-1],
                  RandomT_mbAD,
                  Core_mbAD_T[-1])#remove Intercept

to_gg.mbAD[,":="(Source=gsub("Sp","",Source))] %>% 
  .[,":="(Source=gsub(":","%*%",Source))] %>% 
  .[,":="(Source=gsub("log","",Source))] %>% 
  .[,":="(Source=gsub("DrainCat","Drain",Source))] %>% 
  .[,":="(Source=gsub("Y","Year",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC1","CWM[PC1]",Source))] %>% 
  .[,":="(Source=gsub("CWM.PC2","CWM[PC2]",Source))] %>% 
  .[,":="(Source=gsub("ave","[ave]",Source))] %>% 
  .[,":="(Source=gsub("DIg","DI",Source))]

nr<-nrow(to_gg.mbAD)/3
names_level<-to_gg.mbAD[1:nr,Source]
to_gg.mbAD$Source<-factor(to_gg.mbAD$Source,levels=rev(names_level))

to_gg.mbAD$Model<-factor(to_gg.mbAD$Model,
                         levels=(c("Full dataset",
                                   "Random sampling",
                                   "Subset (≥20 yrs)")))

Grow.mbAD<-ggplot(to_gg.mbAD,aes(x=mean.Grow,xmin=low.Grow,xmax=up.Grow,y=Source,col=Model))+
  geom_vline(aes(xintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(position=position_dodge(0.7),size=1.5)+
  geom_errorbar(position=position_dodge(0.7),width=0)+
  theme_bw()+
  theme(#panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    legend.position=c(0.2,0.2),
    legend.background=element_rect(fill="aliceblue",color=NA),
    axis.text.x=element_text(size=9),
    axis.text.y=element_text(size=9))+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  xlab(expression(paste("Coefficient estimate")))+
  ylab("")+
  scale_y_discrete(labels = scales::parse_format())
Grow.mbAD

Grow_save<-ggarrange(Grow.mb,Grow.mbAD,
                     ncol = 2, nrow = 1,
                     labels = c("A","B"),
                     widths=c(0.45,0.55),
                     font.label = list(size = 13))

ggsave(file="Fig.RS_RandomSampl_Coreset_effect_size.tiff",
       plot=Grow_save,dpi=300,width=10,height=7,compression="lzw")

# Fig. S6 -----------------------------------------------------------------
#https://nigimitama.hatenablog.jp/entry/2018/11/05/021516
#https://bookdown.org/mike/data_analysis/fixest-package.html
#https://ds4ps.org/pe4ps-textbook/docs/p-040-fixed-effects.html
#https://keita43a.hatenablog.com/entry/2020/12/01/202122

library(fixest)

# By fixest -------------------------------------------------------
#Create a dummy variable of time-varying site attributes
arid[,":="(site.by.yeardummy=paste(Eco,FinY))]

#### lognbsp ####
fix_lognbsp<-feols(logAGBGI~lognbsp | PLOT_ID + site.by.yeardummy,arid)
(clSE_lognbsp<-summary(fix_lognbsp)$coeft)

#### logFD ####
fix_logFD<-feols(logAGBGI~logFD | PLOT_ID + site.by.yeardummy,arid)
(clSE_logFD<-summary(fix_logFD)$coeft)

# Accounting for lagged biomass (dynamic panel model) -----------------------------------
#!Use lagged Biomass (IniBio)

#### lognbsp ####
fix_lognbsp2<-feols(logAGBGI~lognbsp+logIniBio | PLOT_ID + site.by.yeardummy,arid)
(clSE2_lognbsp<-summary(fix_lognbsp2)$coeft)

#### logFD ####
fix_logFD2<-feols(logAGBGI~logFD+logIniBio | PLOT_ID + site.by.yeardummy,arid)
(clSE2_logFD<-summary(fix_logFD2)$coeft)

# Bivariate relationship --------------------------------------------------
#### lognbsp ####
bi_lognbsp<-lm(logAGBGI~lognbsp,arid)
summary(bi_lognbsp)$coef["lognbsp",]

#### logFD ####
bi_logFD<-lm(logAGBGI~logFD,arid)
summary(bi_logFD)$coef["logFD",]

# Graphs ------------------------------------------------------------------
#### lognbsp ####
#nbsp model from "6._..."
mb.nbsp<-lmer(logAGBGI~Y+lognbsp+SpCWM.PC1+SpCWM.PC2+MATave+AIave+SI+logSA+
                Y:(lognbsp+SpCWM.PC1+SpCWM.PC2)+
                MATave:(Y+lognbsp+SpCWM.PC1+SpCWM.PC2)+
                AIave:(Y+lognbsp+SpCWM.PC1+SpCWM.PC2)+
                SI:(Y+lognbsp+SpCWM.PC1+SpCWM.PC2)+
                logSA:(Y+lognbsp+SpCWM.PC1+SpCWM.PC2)+
                (1|PLOT_ID),
              control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
              arid)

lognbsp_df<-data.table(mean.Grow=NA,up.Grow=NA,low.Grow=NA,
                       Model=c("Bivariate model",
                               "Linear mixed model",
                               "Fixed effects panel data regression",
                               "Lagged dependent variable design")) %>% data.table() %>% 
  .[,":="(Model=factor(Model,levels = c("Bivariate model",
                                        "Linear mixed model",
                                        "Fixed effects panel data regression",
                                        "Lagged dependent variable design")))]

lognbsp_df[,":="(mean.Grow=c(summary(bi_lognbsp)$coef["lognbsp",1],
                             summary(mb.nbsp)$coef["lognbsp",1],
                             clSE_lognbsp["lognbsp",1],
                             clSE2_lognbsp["lognbsp",1]),
                 up.Grow=c(summary(bi_lognbsp)$coef["lognbsp",1]+summary(bi_lognbsp)$coef["lognbsp",2]*1.96,
                           summary(mb.nbsp)$coef["lognbsp",1]+summary(mb.nbsp)$coef["lognbsp",2]*1.96,
                           clSE_lognbsp["lognbsp",1]+clSE_lognbsp["lognbsp",2]*1.96,
                           clSE2_lognbsp["lognbsp",1]+clSE2_lognbsp["lognbsp",2]*1.96),
                 low.Grow=c(summary(bi_lognbsp)$coef["lognbsp",1]-summary(bi_lognbsp)$coef["lognbsp",2]*1.96,
                            summary(mb.nbsp)$coef["lognbsp",1]-summary(mb.nbsp)$coef["lognbsp",2]*1.96,
                            clSE_lognbsp["lognbsp",1]-clSE_lognbsp["lognbsp",2]*1.96,
                            clSE2_lognbsp["lognbsp",1]-clSE2_lognbsp["lognbsp",2]*1.96))]

lognbsp_graph<-ggplot(lognbsp_df,aes(y=mean.Grow,ymin=low.Grow,ymax=up.Grow,x=Model,col=Model))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(size=6)+
  geom_errorbar(width=0.1)+
  theme_bw()+
  theme(legend.position=c(0.65,0.75),
        legend.text = element_text(size=11),
        legend.background = element_rect(fill="aliceblue",colour=NA),
        axis.text.x=element_blank(),
        axis.title.y = element_text(size=12),
        axis.title.x = element_text(size=14),
        axis.ticks.x = element_blank(),
        axis.text.y=element_text(size=11))+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  ylab(expression(paste("Coefficient estimate")))+
  xlab(expression(paste("Variable: ",italic(ln),"(",italic(S),")")))+
  scale_y_continuous(breaks = c(-0.05,0.0,0.05,0.1),limits = c(-0.05,0.16))
lognbsp_graph

#### logFD ####
logFD_df<-data.table(mean.Grow=NA,up.Grow=NA,low.Grow=NA,
                     Model=c("Bivariate model",
                             "Linear mixed model",
                             "Fixed effects panel data regression",
                             "Lagged dependent variable design")) %>% data.table() %>% 
  .[,":="(Model=factor(Model,levels = c("Bivariate model",
                                        "Linear mixed model",
                                        "Fixed effects panel data regression",
                                        "Lagged dependent variable design")))]

logFD_df[,":="(mean.Grow=c(summary(bi_logFD)$coef["logFD",1],
                           summary(mb)$coef["logFD",1],
                           clSE_logFD["logFD",1],
                           clSE2_logFD["logFD",1]),
               up.Grow=c(summary(bi_logFD)$coef["logFD",1]+summary(bi_logFD)$coef["logFD",2]*1.96,
                         summary(mb)$coef["logFD",1]+summary(mb)$coef["logFD",2]*1.96,
                         clSE_logFD["logFD",1]+clSE_logFD["logFD",2]*1.96,
                         clSE2_logFD["logFD",1]+clSE2_logFD["logFD",2]*1.96),
               low.Grow=c(summary(bi_logFD)$coef["logFD",1]-summary(bi_logFD)$coef["logFD",2]*1.96,
                          summary(mb)$coef["logFD",1]-summary(mb)$coef["logFD",2]*1.96,
                          clSE_logFD["logFD",1]-clSE_logFD["logFD",2]*1.96,
                          clSE2_logFD["logFD",1]-clSE2_logFD["logFD",2]*1.96))]

logFD_graph<-ggplot(logFD_df,aes(y=mean.Grow,ymin=low.Grow,ymax=up.Grow,x=Model,col=Model))+
  geom_hline(aes(yintercept=0),linetype="dashed",colour="grey20")+ 
  geom_point(size=6)+
  geom_errorbar(width=0.1)+
  theme_bw()+
  theme(legend.position="none",
        axis.text.x=element_blank(),
        axis.title.y = element_text(size=12,colour="white"),
        axis.title.x = element_text(size=14),
        axis.ticks.x = element_blank(),
        axis.text.y=element_text(size=11))+
  theme(strip.background = element_blank(), strip.placement = "outside")+
  ylab(expression(paste("Coefficient estimate")))+
  xlab(expression(paste("Variable: ",italic(ln),"(FD)")))+
  scale_y_continuous(breaks = c(-0.05,0.0,0.05,0.1,0.15),limits = c(-0.05,0.17))
logFD_graph

#### Bind graphs ####
Fixed_save<-ggarrange(lognbsp_graph,
                      logFD_graph,
                      ncol = 2, nrow = 1,
                      labels = c("A","B"),
                      font.label = list(size = 14))

ggsave(file="Fig.RS_Fixed_Effect_Modelling_based_on_Dee2023.tiff",
       plot=Fixed_save,dpi=300,width=10,height=6,compression="lzw")

# Fig. S2 -----------------------------------------------------------------
setwd("~/To Figshare")
comp90<-fread("Hisano_SI_MB_Data_90.csv")
comp94<-fread("Hisano_SI_BC_Data_94.csv")

comp90$Threshold<-factor(comp90$Threshold,levels = c("No_threshold","DBH_9.1"))

# Compare AGBGI between different thresholds ----------------------------------------
#### for comp94 ####
#AGBGI
AGBGI_comp94<-lmer(logAGBGI~Threshold+(1|PLOT_ID),
                   control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                   comp94)
summary(AGBGI_comp94)$co
plot_model(AGBGI_comp94,type = "pred",terms = "Threshold")

#SpBio
SpBio_comp94<-lmer(logSpBio~Threshold+(1|PLOT_ID),
                   control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                   comp94)
summary(SpBio_comp94)$co
plot_model(SpBio_comp94,type = "pred",terms = "Threshold")

## Make table ##
#AGBGI
comp94_Productivity<-data.table(Model="Productivity",
                                mean_4.0=NA,up_4.0=NA,low_4.0=NA,
                                mean_9.1=NA,up_9.1=NA,low_9.1=NA)
comp94_Productivity[,":="(mean_4.0=summary(AGBGI_comp94)$co["(Intercept)",1],
                          up_4.0=summary(AGBGI_comp94)$co["(Intercept)",1]+summary(AGBGI_comp94)$co["(Intercept)",2]*1.96,
                          low_4.0=summary(AGBGI_comp94)$co["(Intercept)",1]-summary(AGBGI_comp94)$co["(Intercept)",2]*1.96,
                          
                          mean_9.1=summary(AGBGI_comp94)$co["(Intercept)",1]+summary(AGBGI_comp94)$co["ThresholdDBH_9.1",1],
                          up_9.1=(summary(AGBGI_comp94)$co["(Intercept)",1]+summary(AGBGI_comp94)$co["ThresholdDBH_9.1",1])+
                            (summary(AGBGI_comp94)$co["(Intercept)",2]*1.96+summary(AGBGI_comp94)$co["ThresholdDBH_9.1",2]*1.96),
                          low_9.1=(summary(AGBGI_comp94)$co["(Intercept)",1]+summary(AGBGI_comp94)$co["ThresholdDBH_9.1",1])-
                            (summary(AGBGI_comp94)$co["(Intercept)",2]*1.96+summary(AGBGI_comp94)$co["ThresholdDBH_9.1",2]*1.96))]

#SpBio
comp94_Biomass<-data.table(Model="Standing biomass",
                           mean_4.0=NA,up_4.0=NA,low_4.0=NA,
                           mean_9.1=NA,up_9.1=NA,low_9.1=NA)
comp94_Biomass[,":="(mean_4.0=summary(SpBio_comp94)$co["(Intercept)",1],
                     up_4.0=summary(SpBio_comp94)$co["(Intercept)",1]+summary(SpBio_comp94)$co["(Intercept)",2]*1.96,
                     low_4.0=summary(SpBio_comp94)$co["(Intercept)",1]-summary(SpBio_comp94)$co["(Intercept)",2]*1.96,
                     
                     mean_9.1=summary(SpBio_comp94)$co["(Intercept)",1]+summary(SpBio_comp94)$co["ThresholdDBH_9.1",1],
                     up_9.1=(summary(SpBio_comp94)$co["(Intercept)",1]+summary(SpBio_comp94)$co["ThresholdDBH_9.1",1])+
                       (summary(SpBio_comp94)$co["(Intercept)",2]*1.96+summary(SpBio_comp94)$co["ThresholdDBH_9.1",2]*1.96),
                     low_9.1=(summary(SpBio_comp94)$co["(Intercept)",1]+summary(SpBio_comp94)$co["ThresholdDBH_9.1",1])-
                       (summary(SpBio_comp94)$co["(Intercept)",2]*1.96+summary(SpBio_comp94)$co["ThresholdDBH_9.1",2]*1.96))]

#Combine all
to_gg.comp94<-rbind(comp94_Biomass,comp94_Productivity)
to_gg.comp94 <- melt(setDT(to_gg.comp94), id.vars = "Model", variable.name = "Parameter", value.name = "Value")
to_gg.comp94[,":="(DBHThresh=ifelse(grepl("4.0",to_gg.comp94$Parameter)==TRUE,"4.0 cm","9.1 cm"))] %>% 
  .[,":="(Parameter=gsub("_...","",Parameter))]
to_gg.comp94 <- dcast(to_gg.comp94, Model + DBHThresh ~ Parameter, value.var = "Value")
to_gg.comp94$Model<-factor(to_gg.comp94$Model,levels = c("Standing biomass","Productivity"))
to_gg.comp94<-to_gg.comp94[order(Model)]

summary(SpBio_comp94)$co;summary(AGBGI_comp94)$co
to_gg.comp94$significant <- c(TRUE, TRUE, TRUE, TRUE)
length(unique(comp94[Threshold=="DBH_4.0",PLOT_ID]))
length(unique(comp94[Threshold=="DBH_9.1",PLOT_ID]))

comp94_Threshold<-ggplot(to_gg.comp94, aes(x = DBHThresh, y = exp(mean)-1, ymin=exp(low)-1, ymax=exp(up)-1,
                                           fill = DBHThresh)) +
  geom_bar(stat = "identity", position = "dodge",width = 0.7) +
  geom_errorbar(position = position_dodge(width = 0.8), width = 0.1) +
  scale_fill_manual(values=c("lightgreen","lightblue"),
                    name=expression(paste("DBH threshold")))+
  geom_hline(aes(yintercept=0),linetype="solid",colour="grey20")+ 
  facet_wrap(~paste(Model, ifelse(significant, "(*)", "")), scales = "free") +  # Modified facet_wrap
  theme_classic()+
  labs(title = "British Columbia data",
       x = "",
       y = expression(paste("Unit (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        legend.text = element_text(size=11),
        axis.title.y = element_text(size=12),
        axis.text.x=element_blank(),
        axis.line.x = element_blank(),
        axis.text.y=element_text(size=10),
        axis.ticks.x = element_blank(),
        plot.title=element_text(face="bold"),
        strip.text = element_text(size = 13,face = "bold"),
        strip.background = element_blank())
comp94_Threshold

#### for comp90 ####
#AGBGI
AGBGI_comp90<-lmer(logAGBGI~Threshold+(1|PLOT_ID),
                   control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                   comp90)
summary(AGBGI_comp90)$co
plot_model(AGBGI_comp90,type = "pred",terms = "Threshold")

#SpBio
SpBio_comp90<-lmer(logSpBio~Threshold+(1|PLOT_ID),
                   control=lmerControl(optimizer = "nloptwrap",calc.derivs = FALSE),
                   comp90)
summary(SpBio_comp90)$co
plot_model(SpBio_comp90,type = "pred",terms = "Threshold")

## Make table ##
#AGBGI
comp90_Productivity<-data.table(Model="Productivity",
                                mean_0.0=NA,up_0.0=NA,low_0.0=NA,
                                mean_9.1=NA,up_9.1=NA,low_9.1=NA)
comp90_Productivity[,":="(mean_0.0=summary(AGBGI_comp90)$co["(Intercept)",1],
                          up_0.0=summary(AGBGI_comp90)$co["(Intercept)",1]+summary(AGBGI_comp90)$co["(Intercept)",2]*1.96,
                          low_0.0=summary(AGBGI_comp90)$co["(Intercept)",1]-summary(AGBGI_comp90)$co["(Intercept)",2]*1.96,
                          
                          mean_9.1=summary(AGBGI_comp90)$co["(Intercept)",1]+summary(AGBGI_comp90)$co["ThresholdDBH_9.1",1],
                          up_9.1=(summary(AGBGI_comp90)$co["(Intercept)",1]+summary(AGBGI_comp90)$co["ThresholdDBH_9.1",1])+
                            (summary(AGBGI_comp90)$co["(Intercept)",2]*1.96+summary(AGBGI_comp90)$co["ThresholdDBH_9.1",2]*1.96),
                          low_9.1=(summary(AGBGI_comp90)$co["(Intercept)",1]+summary(AGBGI_comp90)$co["ThresholdDBH_9.1",1])-
                            (summary(AGBGI_comp90)$co["(Intercept)",2]*1.96+summary(AGBGI_comp90)$co["ThresholdDBH_9.1",2]*1.96))]

#SpBio
comp90_Biomass<-data.table(Model="Standing biomass",
                           mean_0.0=NA,up_0.0=NA,low_0.0=NA,
                           mean_9.1=NA,up_9.1=NA,low_9.1=NA)
comp90_Biomass[,":="(mean_0.0=summary(SpBio_comp90)$co["(Intercept)",1],
                     up_0.0=summary(SpBio_comp90)$co["(Intercept)",1]+summary(SpBio_comp90)$co["(Intercept)",2]*1.96,
                     low_0.0=summary(SpBio_comp90)$co["(Intercept)",1]-summary(SpBio_comp90)$co["(Intercept)",2]*1.96,
                     
                     mean_9.1=summary(SpBio_comp90)$co["(Intercept)",1]+summary(SpBio_comp90)$co["ThresholdDBH_9.1",1],
                     up_9.1=(summary(SpBio_comp90)$co["(Intercept)",1]+summary(SpBio_comp90)$co["ThresholdDBH_9.1",1])+
                       (summary(SpBio_comp90)$co["(Intercept)",2]*1.96+summary(SpBio_comp90)$co["ThresholdDBH_9.1",2]*1.96),
                     low_9.1=(summary(SpBio_comp90)$co["(Intercept)",1]+summary(SpBio_comp90)$co["ThresholdDBH_9.1",1])-
                       (summary(SpBio_comp90)$co["(Intercept)",2]*1.96+summary(SpBio_comp90)$co["ThresholdDBH_9.1",2]*1.96))]

#Combine all
to_gg.comp90<-rbind(comp90_Biomass,comp90_Productivity)
to_gg.comp90 <- melt(setDT(to_gg.comp90), id.vars = "Model", variable.name = "Parameter", value.name = "Value")
to_gg.comp90[,":="(DBHThresh=ifelse(grepl("0.0",to_gg.comp90$Parameter)==TRUE,"No threshold","9.1 cm"))] %>% 
  .[,":="(Parameter=gsub("_...","",Parameter))]
to_gg.comp90 <- dcast(to_gg.comp90, Model + DBHThresh ~ Parameter, value.var = "Value")
to_gg.comp90$Model<-factor(to_gg.comp90$Model,levels = c("Standing biomass","Productivity"))
to_gg.comp90<-to_gg.comp90[order(Model)]

summary(SpBio_comp90)$co;summary(AGBGI_comp90)$co
to_gg.comp90$significant <- c(TRUE, TRUE, TRUE, TRUE)
to_gg.comp90$DBHThresh<-factor(to_gg.comp90$DBHThresh,levels = c("No threshold","9.1 cm"))

length(unique(comp90[Threshold=="No_threshold",PLOT_ID]))#1405 plots
length(unique(comp90[Threshold=="DBH_9.1",PLOT_ID]))#938 plots

comp90_Threshold<-ggplot(to_gg.comp90, aes(x = DBHThresh, y = exp(mean)-1, ymin=exp(low)-1, ymax=exp(up)-1,
                                           fill = DBHThresh)) +
  geom_bar(stat = "identity", position = "dodge",width = 0.7) +
  geom_errorbar(position = position_dodge(width = 0.8), width = 0.1) +
  scale_fill_manual(values=c("lightgreen","lightblue"),
                    name=expression(paste("DBH threshold")))+
  geom_hline(aes(yintercept=0),linetype="solid",colour="grey20")+ 
  facet_wrap(~paste(Model, ifelse(significant, "(*)", "")), scales = "free") +  # Modified facet_wrap
  theme_classic()+
  labs(title = "Manitoba data",
       x = "",
       y = expression(paste("Unit (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        legend.text = element_text(size=11),
        axis.title.y = element_text(size=12),
        axis.text.x=element_blank(),
        axis.line.x = element_blank(),
        axis.text.y=element_text(size=10),
        axis.ticks.x = element_blank(),
        plot.title=element_text(face="bold"),
        strip.text = element_text(size = 13,face = "bold"),
        strip.background = element_blank())+ # Remove the background of facet labels
  coord_cartesian(ylim = c(0,NA))
comp90_Threshold

#### Bind figures ####
DBHThreshold_Fig<-ggarrange(comp94_Threshold,comp90_Threshold,
                            labels = c("A","B"),
                            ncol = 1, nrow = 2,
                            font.label = list(size = 14))

setwd("~/To Figshare")
ggsave(file="Fig.S_DBHThreshold.tiff",
       plot=DBHThreshold_Fig,dpi=300,width=7,height=8,compression="lzw")

# Fig. 2 ------------------------------------------------------------------
setwd("~/To Figshare")
trait_arid<-fread("trait_arid_for_PCA.csv")

#Randomize the order of traits, try many times to get your desirable ordination of the PCA
trait_arid2<-trait_arid[,sample(trait_arid[,.(SeedSprR,LMA,LL,WD,ST,Hmat,Lifespan,VegSprR,PercentH,FertReq,Pmass,MoistUse,
                                              DT,Nmass,ST_USDA,FiT,FFDmin,GrowthR,H20, 
                                              RootDepth,SeedAbun,DT_USDA,SeedlVig,SeedMass,HydTh,TheTh,
                                              Amass,Gs,Ks)])]

setnames(trait_arid2,"DT","DTabs");setnames(trait_arid2,"DT_USDA","DTrel");setnames(trait_arid2,"ST","STabs");setnames(trait_arid2,"ST_USDA","STrel")
setnames(trait_arid2,"SeedAbun","SA");setnames(trait_arid2,"SeedMass","SM");setnames(trait_arid2,"SeedSprR","SSR");setnames(trait_arid2,"SeedlVig","SlV")
setnames(trait_arid2,"VegSprR","VSR");setnames(trait_arid2,"RootDepth","SoilDmin")

PCA <- prcomp(trait_arid2,scale=TRUE)
summary(PCA)#PC1 explains 23.8%; PC2 explains 14.4%; totally 38.2%

library(ggfortify)
PCA.auto<-autoplot(prcomp(trait_arid2,scale=TRUE),
                   data=trait_arid,
                   loadings = TRUE, col="Genus", loadings.colour = "lightblue",
                   loadings.label = T,
                   size=3,loadings.label.size = 2,
                   scale=0,shape="Leaf")+
  xlab(expression(paste("PC1 (23.8 %)")))+
  ylab(expression(paste("PC2 (14.4 %)")))+
  theme(panel.border = element_rect(fill = NA, size=0.5),
        panel.background = element_blank())
PCA.auto

setwd("~/To Figshare")
tiff("Fig.RS1_9.1arid_CWM.PCA_Species_with_name.tiff",width=1900,height=1600,res=300,compression="lzw")
grid.arrange(PCA.auto, nrow=1)
#dev.off() #save figure

